RuleNeuroPredictor class

Rule-based predictor implementation

Implemented types

Constructors

RuleNeuroPredictor({NeuroStateModel currentState = const NeuroStateModel()})

Properties

currentState NeuroStateModel
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(String event, Map<String, dynamic> payload) Future<NeuroStateModel>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited